@@ -20,6 +20,7 @@ lazy_static! {
                 ("ALICE/USDT", 0.1_f64),
                 ("ANKR/USDT", 10_f64),
                 ("AR/USDT", 0.1_f64),
+                ("ARPA/USDT", 10_f64),
                 ("ATOM/USDT", 1_f64),
                 ("AVAX/USDT", 1_f64),
                 ("AXS/USDT", 0.1_f64),
@@ -36,8 +37,9 @@ lazy_static! {
                 ("BSV/USDT", 0.01_f64),
                 ("BTC/USDT", 0.001_f64),
                 ("BTS/USDT", 100_f64),
-                ("BTT/USDT", 1000_f64),
+                ("BTT/USDT", 1000000_f64), // changed at 2022-02-28
                 ("C98/USDT", 1_f64),
+                ("CELO/USDT", 0.1_f64),
                 ("CELR/USDT", 10_f64),
                 ("CHR/USDT", 10_f64),
                 ("CHZ/USDT", 10_f64),
@@ -73,12 +75,15 @@ lazy_static! {
                 ("IOST/USDT", 100_f64),
                 ("IOTA/USDT", 10_f64),
                 ("IOTX/USDT", 10_f64),
+                ("JST/USDT", 10_f64),
                 ("KAVA/USDT", 1_f64),
                 ("KNC/USDT", 1_f64),
                 ("KSM/USDT", 0.1_f64),
                 ("LAT/USDT", 10_f64),
                 ("LINA/USDT", 10_f64),
                 ("LINK/USDT", 0.1_f64),
+                ("LOOKS/USDT", 0.1_f64),
+                ("LPT/USDT", 0.01_f64),
                 ("LRC/USDT", 10_f64),
                 ("LTC/USDT", 0.1_f64),
                 ("LUNA/USDT", 1_f64),
@@ -92,6 +97,7 @@ lazy_static! {
                 ("MKR/USDT", 0.001_f64),
                 ("NEAR/USDT", 1_f64),
                 ("NEO/USDT", 0.1_f64),
+                ("NFT/USDT", 1000000_f64),
                 ("NKN/USDT", 10_f64),
                 ("O3/USDT", 1_f64),
                 ("OGN/USDT", 1_f64),
@@ -100,18 +106,23 @@ lazy_static! {
                 ("ONE/USDT", 100_f64),
                 ("ONT/USDT", 10_f64),
                 ("PHA/USDT", 1_f64),
+                ("PEOPLE/USDT", 10_f64),
                 ("QNT/USDT", 0.01_f64),
+                ("PHA/USDT", 1_f64),
                 ("QTUM/USDT", 1_f64),
                 ("REEF/USDT", 100_f64),
                 ("REN/USDT", 10_f64),
                 ("RNDR/USDT", 1_f64),
+                ("ROSE/USDT", 1_f64),
                 ("RSR/USDT", 100_f64),
                 ("RVN/USDT", 10_f64),
                 ("SAND/USDT", 10_f64),
                 ("SHIB/USDT", 1000_f64),
                 ("SKL/USDT", 10_f64),
+                ("SLP/USDT", 100_f64),
                 ("SNX/USDT", 1_f64),
                 ("SOL/USDT", 1_f64),
+                ("SOS/USDT", 100000_f64),
                 ("SRM/USDT", 1_f64),
                 ("STORJ/USDT", 1_f64),
                 ("SUSHI/USDT", 1_f64),
@@ -122,6 +133,7 @@ lazy_static! {
                 ("UMA/USDT", 0.1_f64),
                 ("UNI/USDT", 1_f64),
                 ("VET/USDT", 100_f64),
+                ("VRA/USDT", 100_f64),
                 ("WAVES/USDT", 1_f64),
                 ("WAXP/USDT", 10_f64),
                 ("WOO/USDT", 10_f64),
