@@ -27,6 +27,7 @@ lazy_static! {
                 ("BAND/USDT", 1_f64),
                 ("BAT/USDT", 10_f64),
                 ("BCH/USDT", 0.1_f64),
+                ("BICO/USDT", 1_f64),
                 ("BNT/USDT", 10_f64),
                 ("BSV/USDT", 1_f64),
                 ("BTC/USDT", 0.01_f64),
@@ -85,8 +86,10 @@ lazy_static! {
                 ("MKR/USDT", 0.01_f64),
                 ("NEAR/USDT", 10_f64),
                 ("NEO/USDT", 1_f64),
+                ("NFT/USDT", 1000000_f64),
                 ("OMG/USDT", 1_f64),
                 ("ONT/USDT", 10_f64),
+                ("PEOPLE/USDT", 100_f64),
                 ("PERP/USDT", 1_f64),
                 ("QTUM/USDT", 1_f64),
                 ("REN/USDT", 10_f64),
@@ -98,6 +101,7 @@ lazy_static! {
                 ("SLP/USDT", 10_f64),
                 ("SNX/USDT", 1_f64),
                 ("SOL/USDT", 1_f64),
+                ("SOS/USDT", 1000000_f64),
                 ("SRM/USDT", 1_f64),
                 ("STARL/USDT", 100000_f64),
                 ("STORJ/USDT", 10_f64),
